@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 2726 2009-12-22 05:19:25Z fishbone $
+ * @version    SVN: $Id: m3Func.php 2814 2010-01-29 04:25:40Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -486,12 +486,31 @@ function convFromBytes($val)
  * URL以外をエンティティ文字に変換
  *
  * @param string $src		変換元文字列
+ * @param bool $keepTags	HTMLタグを変換するかどうか
  * @return string			変換後文字列
  */
-function convertToHtmlEntity($src)
+function convertToHtmlEntity($src, $keepTags = false)
 {
 	// 変換文字「&<>"」
-	return htmlentities($src, ENT_COMPAT, M3_HTML_CHARSET);
+	if ($keepTags){			// タグを変換しないとき
+		//$str = "/<[^>]+>/";
+		$str = "/[^<>]+[^<>]/";
+		$dest = preg_replace_callback($str, '_replace_nottag_callback', $src);
+		return $dest;
+	} else {
+		return htmlentities($src, ENT_COMPAT, M3_HTML_CHARSET);
+	}
+}
+/**
+ * タグ以外変換コールバック関数
+ *
+ * @param array $matchData		検索マッチデータ
+ * @return string				変換後データ
+ */
+function _replace_nottag_callback($matchData)
+{
+//echo $matchData[0] .'  --';
+	return htmlentities($matchData[0], ENT_COMPAT, M3_HTML_CHARSET);
 }
 /**
  * URLをエンティティ文字に変換
