@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInitdbWidgetContainer.php 2612 2009-12-04 07:11:09Z fishbone $
+ * @version    SVN: $Id: _installInitdbWidgetContainer.php 2646 2009-12-11 10:49:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -22,7 +22,8 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 	private $sysDb;	// DB接続オブジェクト
 	private $createTableScripts;			// テーブル作成スクリプト
 	private $insertTableScripts;			// データインストールスクリプト
-	const SERVER_ID = 'server_id';
+	const CF_SERVER_ID = 'server_id';
+	const CF_SERVER_URL = 'server_url';		// サーバURL
 	const INSTALL_DT = 'install_dt';		// システムインストール日時
 	const WORK_DIR = 'work_dir';			// 一時ディレクトリ
 	const UPDATE_DIR = 'update';			// 追加スクリプトディレクトリ名
@@ -170,7 +171,8 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 				
 				// 初期値設定
 				$serverId = md5($this->gEnv->getRootUrl() . time());		// サーバID
-				if ($ret) $ret = $this->sysDb->updateSystemConfig(self::SERVER_ID, $serverId);
+				if ($ret) $ret = $this->sysDb->updateSystemConfig(self::CF_SERVER_ID, $serverId);
+				if ($ret) $ret = $this->sysDb->updateSystemConfig(self::CF_SERVER_URL, $this->gEnv->getRootUrl());
 				if ($ret) $ret = $this->sysDb->updateSystemConfig(self::INSTALL_DT, $now);
 				if ($ret) $ret = $this->sysDb->updateSystemConfig(M3_TB_FIELD_DB_UPDATE_DT, $now);
 				//if ($ret) $ret = $this->sysDb->updateSystemConfig(self::WORK_DIR, M3_SYSTEM_WORK_DIR_PATH);// 一時ディレクトリ
