@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsiteWidgetContainer.php 2404 2009-10-10 08:06:10Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsiteWidgetContainer.php 2729 2009-12-22 05:20:08Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainConfigbasicBaseWidgetContainer.php');
@@ -78,9 +78,9 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 			$licenseAddress = $request->trimValueOf('license_address');		// ライセンス住所
 			$licenseFax = $request->trimValueOf('license_fax');		// ライセンスFAX
 			//$siteOwner	= $request->trimValueOf('siteowner');		// サイト所有者
-			//$siteCopyRight	= $request->trimValueOf('sitecopyright');		// サイト著作権
 			$siteName	= $request->trimValueOf('sitename');		// サイト名称
 			$siteEmail	= trim($request->valueOf('siteemail'));		// サイトEメール
+			$siteCopyRight	= $request->trimValueOf('sitecopyright');		// サイト著作権
 			
 			$siteTitle = $request->trimValueOf('site_title');		// 画面タイトル
 			if (empty($siteTitle)) $siteTitle = $siteName;			// タイトル名が設定されていないときはデフォルトでサイト名称を設定
@@ -112,9 +112,6 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 			/*
 			if (!$isErr){
 				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_OWNER, $siteOwner)) $isErr = true;
-			}
-			if (!$isErr){
-				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_COPYRIGHT, $siteCopyRight)) $isErr = true;
 			}*/
 			if (!$isErr){		// サイト名
 				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_NAME, $siteName)) $isErr = true;
@@ -122,6 +119,9 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 			if (!$isErr){
 				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_EMAIL, $siteEmail)) $isErr = true;
 			}
+			if (!$isErr){		// 著作権
+				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_COPYRIGHT, $siteCopyRight)) $isErr = true;
+			}
 			if (!$isErr){
 				if (!$this->db->updateSiteDef($this->defaultLang, M3_TB_FIELD_SITE_TITLE, $siteTitle)) $isErr = true;
 			}
@@ -167,10 +167,11 @@ class admin_mainConfigsiteWidgetContainer extends admin_mainConfigbasicBaseWidge
 		$this->tmpl->addVar("_widget", "license_address", $this->db->getSiteDef($this->defaultLang, self::LICENSE_ADDRESS));
 		$this->tmpl->addVar("_widget", "license_fax", $this->db->getSiteDef($this->defaultLang, self::LICENSE_FAX));
 		/*
-		$this->tmpl->addVar("_widget", "site_owner", $this->gEnv->getSiteOwner(true));
-		$this->tmpl->addVar("_widget", "site_copyright", $this->gEnv->getSiteCopyRight(true));*/
+		$this->tmpl->addVar("_widget", "site_owner", $this->gEnv->getSiteOwner(true));*/
 		$this->tmpl->addVar("_widget", "site_name", $this->gEnv->getSiteName(true));		// サイト名
 		$this->tmpl->addVar("_widget", "site_email", $siteEmail);
+		$this->tmpl->addVar("_widget", "site_copyright", $this->gEnv->getSiteCopyRight(true));	// 著作権
+		
 		// SEO
 		$this->tmpl->addVar("_widget", "site_title", $this->db->getSiteDef($this->defaultLang, M3_TB_FIELD_SITE_TITLE));
 		$this->tmpl->addVar("_widget", "site_desc", $this->db->getSiteDef($this->defaultLang, M3_TB_FIELD_SITE_DESCRIPTION));
