@@ -10,10 +10,9 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 2438 2009-10-21 05:25:42Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 2677 2009-12-14 05:40:23Z fishbone $
  * @link       http://www.magic3.org
  */
-//require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 
@@ -40,6 +39,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainBaseWidgetContainer
 	const CF_USE_PAGE_CACHE = 'use_page_cache';		// 画面キャッシュ機能を使用するかどうか
 	const CF_USE_TEMPLATE_ID_IN_SESSION = 'use_template_id_in_session';			// セッションにテンプレートIDを保存
 	const CF_SSL_URL = 'ssl_root_url';				// SSL用のルートURL
+	const CF_CONNECT_SERVER_URL = 'default_connect_server_url';			// ポータル接続先URL
 	const INSTALL_DT = 'install_dt';		// システムインストール日時
 	const WORK_DIR = 'work_dir';			// 作業ディレクトリ
 	const WRITE_TEST_FILENAME = '_magic3_test';			// 書き込みテスト用ファイル名
@@ -86,6 +86,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainBaseWidgetContainer
 		$useSsl = ($request->trimValueOf('item_use_ssl') == 'on') ? 1 : 0;		// SSL機能を使用するかどうか
 		$useSslAdmin = ($request->trimValueOf('item_use_ssl_admin') == 'on') ? 1 : 0;		// 管理画面にSSL機能を使用するかどうか
 		$sslUrl = $request->trimValueOf('item_ssl_url');			// SSL用のURL
+		$connectServerUrl = $request->trimValueOf('item_connect_server_url');			// ポータル接続先URL
 		$usePageCache = ($request->trimValueOf('item_use_page_cache') == 'on') ? 1 : 0;		// 表示キャッシュ機能を使用するかどうか
 		$canChangeTemplate = ($request->trimValueOf('item_can_change_template') == 'on') ? 1 : 0;		// ユーザによるテンプレート変更を許可するかどうか
 		$canDetailConfig = ($request->trimValueOf('item_can_detail_config') == 'on') ? 1 : 0;		// 詳細システム設定が可能かどうか
@@ -139,6 +140,10 @@ class admin_mainConfigsysWidgetContainer extends admin_mainBaseWidgetContainer
 				$sslUrl = str_replace('http://', 'https://', $sslUrl);// httpの場合はhttpsに変更
 				if (!$this->db->updateSystemConfig(self::CF_SSL_URL, $sslUrl)) $isErr = true;
 			}
+			if (!$isErr){
+				$connectServerUrl = rtrim($connectServerUrl, '/');// 最後の「/」を除く
+				if (!$this->db->updateSystemConfig(self::CF_CONNECT_SERVER_URL, $connectServerUrl)) $isErr = true;// ポータル接続先URL
+			}
 			if (!$isErr){
 				$workDir = rtrim($workDir, '/');// 最後の「/」を除く
 				if (!$this->db->updateSystemConfig(self::WORK_DIR, $workDir)) $isErr = true;
@@ -157,6 +162,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainBaseWidgetContainer
 			$useSsl				= $this->db->getSystemConfig(self::CF_USE_SSL);			// SSL機能を使用するかどうか
 			$useSslAdmin		= $this->db->getSystemConfig(self::CF_USE_SSL_ADMIN);			// SSL機能を使用するかどうか
 			$sslUrl				= $this->db->getSystemConfig(self::CF_SSL_URL);			// SSLのURL
+			$connectServerUrl	= $this->db->getSystemConfig(self::CF_CONNECT_SERVER_URL);// ポータル接続先URL
 			$usePageCache 		= $this->db->getSystemConfig(self::CF_USE_PAGE_CACHE);			// 表示キャッシュ機能を使用するかどうか
 			$canChangeTemplate	= $this->db->getSystemConfig(self::CF_USE_TEMPLATE_ID_IN_SESSION);// ユーザによるテンプレート変更を許可するかどうか
 			$canDetailConfig	= $this->db->getSystemConfig(self::CAN_DETAIL_CONFIG);
@@ -202,6 +208,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainBaseWidgetContainer
 			$useSsl				= $this->db->getSystemConfig(self::CF_USE_SSL);			// SSL機能を使用するかどうか
 			$useSslAdmin		= $this->db->getSystemConfig(self::CF_USE_SSL_ADMIN);			// SSL機能を使用するかどうか
 			$sslUrl				= $this->db->getSystemConfig(self::CF_SSL_URL);			// SSLのURL
+			$connectServerUrl	= $this->db->getSystemConfig(self::CF_CONNECT_SERVER_URL);// ポータル接続先URL
 			$usePageCache 		= $this->db->getSystemConfig(self::CF_USE_PAGE_CACHE);			// 表示キャッシュ機能を使用するかどうか
 			$canChangeTemplate	= $this->db->getSystemConfig(self::CF_USE_TEMPLATE_ID_IN_SESSION);// ユーザによるテンプレート変更を許可するかどうか
 			$canDetailConfig	= $this->db->getSystemConfig(self::CAN_DETAIL_CONFIG);
@@ -226,8 +233,9 @@ class admin_mainConfigsysWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar("_widget", "mobile_encode", $this->gEnv->getMobileEncoding());
 		
 		// サイト運用状況を設定
-		if ($this->db->getSystemConfig(self::SITE_IN_PUBLIC)){		// 運用中のとき
-			$this->tmpl->addVar("_widget", "site_open", '公開中');
+		//if ($this->db->getSystemConfig(self::SITE_IN_PUBLIC)){		// 運用中のとき
+		if ($this->gSystem->siteInPublic(true/*再取得*/)){		// 運用中のとき
+			$this->tmpl->addVar("_widget", "site_open", '<b><font color="green">公開中</font></b>');
 			$this->tmpl->addVar("_widget", "site_open_status", '0');
 			$this->tmpl->addVar("_widget", "site_open_label", '公開停止');
 		} else {
@@ -261,6 +269,7 @@ class admin_mainConfigsysWidgetContainer extends admin_mainBaseWidgetContainer
 
 		$this->tmpl->addVar("_widget", "root_url", $this->gEnv->getRootUrl());
 		$this->tmpl->addVar("_widget", "ssl_url", $sslUrl);// SSLのURL
+		$this->tmpl->addVar("_widget", "connect_server_url", $connectServerUrl);// ポータル接続先URL
 		
 		$checked = '';
 		if ($canDetailConfig) $checked = 'checked';
@@ -360,6 +369,13 @@ class admin_mainConfigsysWidgetContainer extends admin_mainBaseWidgetContainer
 			$data = '<b><font color="red">Off</font></b>';
 		}
 		$this->tmpl->addVar("_widget","current_xml", $data);
+		// curl
+		if (extension_loaded('curl')){
+			$data = '<b><font color="green">On</font></b>';
+		} else {
+			$data = '<b><font color="red">Off</font></b>';
+		}
+		$this->tmpl->addVar("_widget","current_curl", $data);
 		
 		// サーバ環境
 		$hostname = exec('hostname');
