@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainPageinfoWidgetContainer.php 2711 2009-12-19 05:12:31Z fishbone $
+ * @version    SVN: $Id: admin_mainPageinfoWidgetContainer.php 2732 2009-12-24 01:31:40Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainMasterBaseWidgetContainer.php');
@@ -42,9 +42,12 @@ class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContai
 		
 		// コンテンツタイプ
 		$this->contentTypeArray = array(	array(	'name' => '指定なし',					'value' => ''),
-											array(	'name' => '標準コンテンツ(content)',	'value' => 'content'),
-											array(	'name' => '製品(product)',				'value' => 'product'),
-											array(	'name' => 'Wiki(wiki)',					'value' => 'wiki'));
+											array(	'name' => '汎用コンテンツ',				'value' => M3_VIEW_TYPE_CONTENT),
+											array(	'name' => '製品',						'value' => M3_VIEW_TYPE_PRODUCT),
+											array(	'name' => 'BBS',						'value' => M3_VIEW_TYPE_BBS),
+											array(	'name' => 'ブログ',						'value' => M3_VIEW_TYPE_BLOG),
+											array(	'name' => 'Wiki',						'value' => M3_VIEW_TYPE_WIKI),
+											array(	'name' => 'ユーザ作成コンテンツ',		'value' => M3_VIEW_TYPE_USER));
 	}
 	/**
 	 * テンプレートファイルを設定
