@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 2533 2009-11-10 02:38:12Z fishbone $
+ * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 2636 2009-12-08 04:05:48Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -191,6 +191,12 @@ class admin_mainTemplistWidgetContainer extends admin_mainBaseWidgetContainer
 					$this->setAppErrorMsg($msg);
 				}
 				
+				// テンポラリディレクトリの書き込み権限をチェック
+				if (!is_writable($this->gEnv->getWorkDirPath())){
+					$msg = '一時ディレクトリに書き込み権限がありません。ディレクトリ：' . $this->gEnv->getWorkDirPath();
+					$this->setAppErrorMsg($msg);
+				}
+				
 				if ($this->getMsgCount() == 0){		// エラーが発生していないとき
 					// ファイルを保存するサーバディレクトリを指定
 					$tmpFile = tempnam($this->gEnv->getWorkDirPath(), M3_SYSTEM_WORK_UPLOAD_FILENAME_HEAD);
