@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 2596 2009-11-26 02:02:44Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 2708 2009-12-18 09:00:15Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -861,38 +861,6 @@ class admin_mainDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
-	/**
-	 * ページIDの更新
-	 *
-	 * @param int $type				リストの種別
-	 * @param array  $rows			更新データ
-	 * @return bool					true=成功、false=失敗
-	 */
-	/*function updatePageId($type, $rows)
-	{
-		// トランザクション開始
-		$this->startTransaction();
-		
-		for ($i = 0; $i < count($rows); $i++){
-			// 既存項目を更新
-			$queryStr  = 'UPDATE _page_id ';
-			$queryStr .=   'SET ';
-			$queryStr .=     'pg_default_sub_id = ?, ';
-			$queryStr .=     'pg_path = ?, ';
-			$queryStr .=     'pg_name = ?, ';
-			$queryStr .=     'pg_description = ?, ';
-			$queryStr .=     'pg_priority = ?, ';
-			$queryStr .=     'pg_active = ? ';
-			$queryStr .=   'WHERE pg_id = ? ';
-			$queryStr .=     'AND pg_type = ? ';
-			$queryStr .=     'AND pg_editable = true ';		// 編集可能項目のみ更新
-			$this->execStatement($queryStr, array($rows[$i]['pg_default_sub_id'], $rows[$i]['pg_path'], $rows[$i]['pg_name'], 
-								$rows[$i]['pg_description'], $rows[$i]['pg_priority'], $rows[$i]['pg_active'], $rows[$i]['pg_id'], $type));
-		}
-		// トランザクション確定
-		$ret = $this->endTransaction();
-		return $ret;
-	}*/
 	/**
 	 * ページポジションのリストを取得
 	 *
@@ -2407,7 +2375,7 @@ class admin_mainDb extends BaseDb
 	 * @param array $serial			メニューIDの配列
 	 * @return						true=成功、false=失敗
 	 */
-	function delMenuIdBySerial($serial)
+	function delMenuId($serial)
 	{
 		// 引数のエラーチェック
 		if (!is_array($serial)) return false;
@@ -2417,6 +2385,7 @@ class admin_mainDb extends BaseDb
 		$this->startTransaction();
 		
 		// 指定のシリアルNoのレコードが削除状態でないかチェック
+		$delId = '';
 		for ($i = 0; $i < count($serial); $i++){
 			$queryStr  = 'SELECT * FROM _menu_id ';
 			$queryStr .=   'WHERE mn_id = ? ';
@@ -2426,11 +2395,13 @@ class admin_mainDb extends BaseDb
 				$this->endTransaction();
 				return false;
 			}
+			$delId .= '\'' . addslashes($serial[$i]) . '\',';
 		}
+		$delId = rtrim($delId, ',');
 		
 		// データ削除
 		$queryStr  = 'DELETE FROM _menu_id ';
-		$queryStr .=   'WHERE mn_id in (' . implode($serial, ',') . ') ';
+		$queryStr .=   'WHERE mn_id in (' . $delId . ') ';
 		$this->execStatement($queryStr, array());
 		
 		// トランザクション確定
