@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 2734 2009-12-25 05:51:56Z fishbone $
+ * @version    SVN: $Id: index.php 2780 2010-01-15 05:36:30Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -455,6 +455,8 @@ $HELP['filebrowse_date']['title'] = '更新日時';
 $HELP['filebrowse_date']['body'] = 'ファイル、ディレクトリの更新日時を示します。';
 $HELP['filebrowse_upload_status']['title'] = 'ファイルアップロード状況';
 $HELP['filebrowse_upload_status']['body'] = 'ファイルのアップロードはここから行います。ファイルアップロード時はアップロード状況が表示されます。';
+$HELP['filebrowse_del_btn']['title'] = '削除ボタン';
+$HELP['filebrowse_del_btn']['body'] = '選択されているメニュー項目を削除します。<br />メニュー項目を選択するには、一覧の左端のチェックボックスにチェックを入れます。<br />「resource」ディレクトリ以下のファイルのみ削除可能です。';
 
 // ########## テナントサーバ管理 ##########
 $HELP['tenantserver']['title'] = 'テナントサーバ管理';
